import{d as b,eI as g,r as y,I as v,b as h,eu as k,f as c,u as t,v as w}from"./outputWidgets.260a3c99.js";import{g as I}from"./api.8917e54c.js";import{a as m}from"./asyncComputed.61df0e0c.js";import{P as H}from"./PlayerNavbar.2e825223.js";import{H as D}from"./HomeContent.01e82d7d.js";import{u as s}from"./index.76924dfa.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./PhKanban.vue.ac9ff90f.js";import"./PhSignOut.vue.7cf286a2.js";import"./Text.3b774738.js";import"./index.5bcf94e8.js";import"./Link.e028ce0e.js";import"./Paragraph.482f5128.js";import"./Title.9673e08a.js";import"./index.b2703a93.js";import"./PhArrowSquareOut.vue.fc3fa822.js";import"./index.38e39792.js";import"./Card.a6a7eb10.js";import"./index.8ca3bef1.js";import"./TabPane.ccb73962.js";import"./hasIn.8ab3cbf4.js";import"./index.34fd2dd9.js";import"./pubsub.ab27f2c0.js";import"./fetch.642bd10d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="1486d9a4-6dfc-4cbc-9994-bddaa8c6c494",o._sentryDebugIdIdentifier="sentry-dbid-1486d9a4-6dfc-4cbc-9994-bddaa8c6c494")}catch{}})();const x={class:"page"},C=b({__name:"Home",setup(o){const e=g(),r=y(s.getUser()),{result:p,refetch:d}=m(async()=>(await s.allow("kanban")).status==="ALLOWED");v(r,()=>d());const u=({path:a})=>{e.push({name:"form",params:{path:a.split("/")}})},{result:n,loading:l}=m(I),f=a=>{e.push({path:`/${a}`})},_=()=>{s.removeUser(),e.push({name:"playerHome"})};return(a,L)=>{var i;return h(),k("div",x,[c(H,{"runner-data":t(n),"is-kanban-visible":t(p)||!1,"user-email":(i=r.value)==null?void 0:i.claims.email,onNavigate:u,onLogout:_},null,8,["runner-data","is-kanban-visible","user-email"]),c(D,{workspace:t(n),loading:t(l),onFormClick:f},null,8,["workspace","loading"])])}}});const ee=w(C,[["__scopeId","data-v-f12c98c4"]]);export{ee as default};
//# sourceMappingURL=Home.5b5feea1.js.map
