.collapsible[data-v-389b3583]{display:flex;justify-content:end;padding:0 8px;cursor:pointer;margin-top:auto;margin-bottom:20px}.disabled[data-v-389b3583]{cursor:not-allowed;opacity:.4}.logo[data-v-81cd596e]{display:flex;align-items:center}.logo img[data-v-81cd596e]{height:30px}.logo span[data-v-81cd596e]{font-size:18px;font-weight:600;margin-left:10px}
