import{U as s,f as p,O as d}from"./outputWidgets.260a3c99.js";import{B as f,b as i}from"./Text.3b774738.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="2dd6efb7-f663-4056-97a9-741025c2fb1f",e._sentryDebugIdIdentifier="sentry-dbid-2dd6efb7-f663-4056-97a9-741025c2fb1f")}catch{}})();const y=()=>d(i(),["component"]),a=(e,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},e),{component:"div"}),o);return p(f,n,t)};a.displayName="ATypographyParagraph";a.inheritAttrs=!1;a.props=y();const g=a;export{g as A};
//# sourceMappingURL=Paragraph.482f5128.js.map
