import{P as h}from"./PlayerNavbar.2e825223.js";import{g as b}from"./api.8917e54c.js";import{a as d}from"./asyncComputed.61df0e0c.js";import{W as v}from"./WidgetsFrame.8e64f431.js";import{d as w,r as k,I,eI as D,eA as x,b as p,eu as C,e as o,f as E,u as a,c as N,w as P,ew as V,eD as f,v as A}from"./outputWidgets.260a3c99.js";import{u as n}from"./index.76924dfa.js";import"./PhKanban.vue.ac9ff90f.js";import"./PhSignOut.vue.7cf286a2.js";import"./Text.3b774738.js";import"./index.5bcf94e8.js";import"./Link.e028ce0e.js";import"./Paragraph.482f5128.js";import"./Title.9673e08a.js";import"./index.b2703a93.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./pubsub.ab27f2c0.js";import"./fetch.642bd10d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new q().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="a3c2384e-1440-44c4-ba5a-336e59aadfd1",t._sentryDebugIdIdentifier="sentry-dbid-a3c2384e-1440-44c4-ba5a-336e59aadfd1")}catch{}})();const B={class:"error"},L={class:"inner-content"},W=w({__name:"Error",setup(t){const r=k(n.getUser()),{result:i,refetch:_}=d(async()=>(await n.allow("kanban")).status==="ALLOWED");I(r,()=>_());const u=D(),g=({path:e})=>{u.push({name:"form",query:c.query,params:{path:e.split("/")}})},c=x(),{result:s}=d(b),y=()=>{n.removeUser(),u.push({name:"playerHome"})},m=()=>{const{status:e}=c.params;switch(e){case"404":return{status:e,message:"Page not found."};case"403":return{status:e,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(e,F)=>{var l;return p(),C("div",null,[o("div",B,[E(h,{"user-email":(l=r.value)==null?void 0:l.claims.email,"is-kanban-visible":a(i)||!1,"runner-data":a(s),onNavigate:g,onLogout:y},null,8,["user-email","is-kanban-visible","runner-data"]),a(s)?(p(),N(v,{key:0,"main-color":a(s).mainColor,theme:a(s).theme,"font-family":a(s).fontFamily,style:{height:"100vh",width:"100%"}},{default:P(()=>[o("div",L,[o("h1",null,f(m().status),1),o("p",null,f(m().message),1)])]),_:1},8,["main-color","theme","font-family"])):V("",!0)])])}}});const q=A(W,[["__scopeId","data-v-98d8191f"]]);export{q as default};
//# sourceMappingURL=Error.8c6d531c.js.map
