import{v as r,a,b as i,c,j as d,T as p,k as _,P as u,C as f,M as l,s as g,l as s,m,n as y,p as b,q as v}from"./outputWidgets.260a3c99.js";import{s as w,a as o}from"./index.76924dfa.js";import"./pubsub.ab27f2c0.js";import"./fetch.642bd10d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="368965b6-a818-41d1-9555-234d270a749c",e._sentryDebugIdIdentifier="sentry-dbid-368965b6-a818-41d1-9555-234d270a749c")}catch{}})();const h={};function I(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>m(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.72d7deda.js.map
