import{K as n,E as a,L as p}from"./repository.69b3cc6b.js";import{d as s,b as m,c,u as e}from"./outputWidgets.260a3c99.js";import{l as f}from"./fetch.642bd10d.js";import"./asyncComputed.61df0e0c.js";import"./workspaces.2f7f8b14.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./record.608c7c8c.js";import"./pubsub.ab27f2c0.js";import"./scripts.7e47dba2.js";import"./envVars.6745b705.js";import"./api.24a1a6cb.js";import"./index.cf4c23b9.js";import"./metadata.1f8b8ac9.js";import"./PhCheckCircle.vue.8c5f3095.js";import"./PhScroll.vue.87452035.js";import"./PhWebhooksLogo.vue.f190657b.js";import"./ant-design.16592543.js";import"./index.30985d18.js";import"./Modal.6a26a016.js";import"./Text.3b774738.js";import"./index.34fd2dd9.js";import"./index.a74fba23.js";import"./index.233d86bf.js";import"./Paragraph.482f5128.js";import"./index.5bcf94e8.js";import"./Link.e028ce0e.js";import"./Title.9673e08a.js";import"./index.ede42218.js";import"./CollapsePanel.e726c946.js";import"./index.1545a14c.js";import"./index.2a90a136.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.ee180c2e.js";import"./Card.a6a7eb10.js";import"./index.8ca3bef1.js";import"./TabPane.ccb73962.js";import"./hasIn.8ab3cbf4.js";import"./vuedraggable.umd.e50b8ef5.js";import"./index.f8d85462.js";import"./Form.46e378f9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="aaae45bf-ac14-49f3-ae45-c30802ed0f41",t._sentryDebugIdIdentifier="sentry-dbid-aaae45bf-ac14-49f3-ae45-c30802ed0f41")}catch{}})();class d{constructor(o=f){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const ro=s({__name:"WorkflowKanban",setup(t){const o=new a,r=new d,i=new p("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{ro as default};
//# sourceMappingURL=WorkflowKanban.5cba7725.js.map
