.flex-row[data-v-dc7e11a2]{display:flex;flex-direction:row;align-items:center;justify-content:right;gap:5px;height:100%;width:100%}.trigger-buttons[data-v-884655a9]{display:flex;gap:8px;font-size:14px;color:gray}.trigger-buttons>*[data-v-884655a9]{cursor:pointer}.trigger-buttons>*[data-v-884655a9] :hover{color:#f28392}.trigger-buttons>*[data-v-884655a9] :active{color:#f28392}.centered[data-v-884655a9]{display:flex;flex-direction:column;gap:16px;padding:32px}
