import{D as l}from"./DeleteOutlined.f8ba9770.js";import{f as u,eG as o}from"./outputWidgets.260a3c99.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9241435b-d7a2-4b72-92b6-88ffc248e5af",e._sentryDebugIdIdentifier="sentry-dbid-9241435b-d7a2-4b72-92b6-88ffc248e5af")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(f){return Object.getOwnPropertyDescriptor(n,f).enumerable}))),r.forEach(function(f){d(e,f,n[f])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=i({},t,n.attrs);return u(o,i({},r,{icon:l}),null)};a.displayName="DeleteOutlined";a.inheritAttrs=!1;const s=a;export{s as D};
//# sourceMappingURL=DeleteOutlined.d3e3dde5.js.map
