import{eW as t,eX as r}from"./outputWidgets.260a3c99.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="68133285-53b7-47d0-965c-c6a2c7edc50c",e._sentryDebugIdIdentifier="sentry-dbid-68133285-53b7-47d0-965c-c6a2c7edc50c")}catch{}})();function s(e,n){return t(1,arguments),r(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.233d86bf.js.map
