.error[data-v-3e46b76c]{display:flex;flex-direction:column;align-items:center;justify-content:center;width:100%;height:100%;background-color:#f5f5f5}.error-header[data-v-3e46b76c]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100px;width:100%;box-sizing:border-box}.error-body[data-v-3e46b76c],.error-message[data-v-3e46b76c],.error-actions[data-v-3e46b76c]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;width:100%;box-sizing:border-box}.error-details[data-v-3e46b76c]{padding:1rem;color:red;border:1px solid red;background-color:#fff;border-radius:5px}[data-v-f34f7ac4]:root{--main-font-family: DM Sans, sans-serif}[data-v-f34f7ac4]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-f34f7ac4]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-f34f7ac4]{background-color:#fff;padding:10px}.back-btn[data-v-f34f7ac4]{cursor:pointer;display:flex;justify-content:center;align-items:center;gap:6px;padding:7px 14px;font-family:DM Sans,sans-serif;font-style:normal;font-weight:500;font-size:16px;line-height:20px;color:#5a677a;border:none;background:transparent;background:rgba(255,255,255,.9);box-shadow:0 0 4px #0000001f;border-radius:4px;position:fixed;bottom:48px;right:24px}[data-v-2b94eb6e]:root{--main-font-family: DM Sans, sans-serif}[data-v-2b94eb6e]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-2b94eb6e]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-2b94eb6e]{background-color:#fff;padding:10px}.page[data-v-2b94eb6e]{display:flex;flex-direction:column;height:100%}.loading[data-v-2b94eb6e]{display:flex;justify-content:center;flex-direction:column;align-items:center;height:100%}
