import{F as t}from"./Form.46e378f9.js";import{b1 as f,cl as n}from"./outputWidgets.260a3c99.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c0769ffa-a51f-4158-9312-1960b6f6a4c4",e._sentryDebugIdIdentifier="sentry-dbid-c0769ffa-a51f-4158-9312-1960b6f6a4c4")}catch{}})();t.useInjectFormItemContext=f;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.f8d85462.js.map
