import{v as t,b as s,eu as d}from"./outputWidgets.260a3c99.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="664c6311-39d8-4ad2-be7c-b5735ca14bdd",e._sentryDebugIdIdentifier="sentry-dbid-664c6311-39d8-4ad2-be7c-b5735ca14bdd")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.8442deab.js.map
