import{g as m}from"./api.8917e54c.js";import{P as c}from"./Passwordless.762d1b08.js";import{a as f}from"./asyncComputed.61df0e0c.js";import{W as p}from"./WidgetsFrame.8e64f431.js";import{d as u,eI as l,eA as _,b as i,eu as y,e as g,u as a,c as w,w as b,ew as h,f as v,v as I}from"./outputWidgets.260a3c99.js";import{u as k}from"./index.76924dfa.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./index.1d812c5e.js";import"./PhArrowClockwise.vue.88725f38.js";import"./CircularLoading.5c33d6d2.js";import"./pubsub.ab27f2c0.js";import"./fetch.642bd10d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2f55a03d-2811-4f80-89cd-75ae86adb8d7",e._sentryDebugIdIdentifier="sentry-dbid-2f55a03d-2811-4f80-89cd-75ae86adb8d7")}catch{}})();const x={class:"login"},C=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=f(m),d=async()=>{await k.signUp();const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[g("div",x,[a(o)?(i(),w(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:b(()=>[v(c,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):h("",!0)])]))}});const M=I(C,[["__scopeId","data-v-73f41769"]]);export{M as default};
//# sourceMappingURL=Login.ae88e6ae.js.map
