.page[data-v-f12c98c4]{display:flex;flex-direction:column;height:100%}.container[data-v-f12c98c4]{display:flex;justify-content:center;align-items:center;width:100%;flex:1}.form-card[data-v-f12c98c4]{cursor:pointer}.form-card[data-v-f12c98c4]:hover{box-shadow:0 0 10px #0000001a}
