import{d as y,r as v,I as x,o as V,eL as u,b as c,c as f,w as o,f as t,u as e,aq as h,cC as A,e as s,eD as _,by as D}from"./outputWidgets.260a3c99.js";import{d as I}from"./vuedraggable.umd.e50b8ef5.js";import{_ as S}from"./SaveButton.vue_vue_type_script_setup_true_lang.3b17b3c2.js";import{A as C}from"./Item.09282896.js";import{A as L}from"./index.f16fa6f5.js";import{A as w}from"./Title.9673e08a.js";import{A as g}from"./index.34fd2dd9.js";import{A as b}from"./index.1545a14c.js";import{A as E,F}from"./Form.46e378f9.js";import{W as U}from"./workspaces.2f7f8b14.js";import{a as $}from"./asyncComputed.61df0e0c.js";import"./envVars.6745b705.js";import{L as B}from"./CircularLoading.5c33d6d2.js";import{S as N}from"./SidebarPreview.9a1dbffc.js";import"./UnsavedChangesHandler.76a1ee3f.js";import"./ExclamationCircleOutlined.e45bcfce.js";import"./Modal.6a26a016.js";import"./Text.3b774738.js";import"./Link.e028ce0e.js";import"./hasIn.8ab3cbf4.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./record.608c7c8c.js";import"./pubsub.ab27f2c0.js";import"./PlayerNavbar.2e825223.js";import"./PhKanban.vue.ac9ff90f.js";import"./PhSignOut.vue.7cf286a2.js";import"./index.5bcf94e8.js";import"./Paragraph.482f5128.js";import"./index.b2703a93.js";import"./WidgetsFrame.8e64f431.js";import"./HomeContent.01e82d7d.js";import"./PhArrowSquareOut.vue.fc3fa822.js";import"./index.38e39792.js";import"./Card.a6a7eb10.js";import"./index.8ca3bef1.js";import"./TabPane.ccb73962.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[a]="3e27fd5a-ffaa-4304-9aaa-7244cf7bda91",r._sentryDebugIdIdentifier="sentry-dbid-3e27fd5a-ffaa-4304-9aaa-7244cf7bda91")}catch{}})();const T=s("span",null,"Route",-1),j=s("span",null,"Title",-1),q=s("span",null,"Visible",-1),M={style:{flex:"1 0"}},R={style:{flex:"1 0"}},W=y({__name:"SidebarEditor",props:{modelValue:{},workspace:{}},emits:["update:modelValue"],setup(r,{emit:a}){const p=r,i=v([]),n=()=>a("update:modelValue",i.value);return x(()=>p.modelValue,(d,m)=>{u.exports.isEqual(d,m)||(i.value=u.exports.cloneDeep(d))}),V(()=>{i.value=u.exports.cloneDeep(p.modelValue)}),(d,m)=>(c(),f(e(E),{help:"Change your sidebar items position and visibility by dragging them up and down"},{default:o(()=>[t(e(g),{justify:"space-between",style:{margin:"0 0 12px 0"}},{default:o(()=>[t(e(w),{level:4,style:{margin:"0"}},{default:o(()=>[h("Sidebar items")]),_:1}),t(S,{model:d.workspace},null,8,["model"])]),_:1}),t(e(L),{bordered:""},{header:o(()=>[t(e(A),{style:{width:"100%","justify-content":"space-between"}},{default:o(()=>[T,t(e(b),{type:"vertical"}),j,t(e(b),{type:"vertical"}),q]),_:1})]),default:o(()=>[t(e(I),{modelValue:i.value,"onUpdate:modelValue":m[0]||(m[0]=l=>i.value=l),style:{width:"100%"},onChange:n},{item:o(({element:l})=>[t(e(C),{style:{cursor:"ns-resize"}},{default:o(()=>[s("span",M,"/"+_(l.path),1),s("span",R,_(l.name),1),t(e(D),{checked:l.visible,"onUpdate:checked":k=>l.visible=k,type:"checkbox",onChange:n},null,8,["checked","onUpdate:checked"])]),_:2},1024)]),_:1},8,["modelValue"])]),_:1})]),_:1}))}}),z={style:{width:"50%"}},P={style:{width:"50%"}},Se=y({__name:"SidebarEditor",setup(r){const{result:a,loading:p}=$(()=>U.get());return(i,n)=>e(p)||!e(a)?(c(),f(B,{key:0})):(c(),f(e(F),{key:1,style:{width:"100%",padding:"40px 120px"}},{default:o(()=>[t(e(w),null,{default:o(()=>[h("Sidebar")]),_:1}),t(e(g),{gap:"40"},{default:o(()=>[s("div",z,[t(W,{modelValue:e(a).sidebar,"onUpdate:modelValue":n[0]||(n[0]=d=>e(a).sidebar=d),workspace:e(a)},null,8,["modelValue","workspace"])]),s("div",P,[t(N,{workspace:e(a),"widgets-visible":!1},null,8,["workspace"])])]),_:1})]),_:1}))}});export{Se as default};
//# sourceMappingURL=SidebarEditor.c72a8fea.js.map
