import{d as A,L as E,f as o,a5 as p,X as M,r as O,af as w,ap as N,Q as $,N as T,e7 as k,dl as D}from"./outputWidgets.260a3c99.js";import{C as P}from"./Form.46e378f9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[c]="43134fbf-b238-4b35-a3d8-fafddaf89aeb",t._sentryDebugIdIdentifier="sentry-dbid-43134fbf-b238-4b35-a3d8-fafddaf89aeb")}catch{}})();const K=()=>({avatar:p.any,description:p.any,prefixCls:String,title:p.any}),F=A({compatConfig:{MODE:3},name:"AListItemMeta",props:K(),displayName:"AListItemMeta",__ANT_LIST_ITEM_META:!0,slots:Object,setup(t,c){let{slots:e}=c;const{prefixCls:a}=E("list",t);return()=>{var n,f,m,y,b,l;const s=`${a.value}-item-meta`,i=(n=t.title)!==null&&n!==void 0?n:(f=e.title)===null||f===void 0?void 0:f.call(e),r=(m=t.description)!==null&&m!==void 0?m:(y=e.description)===null||y===void 0?void 0:y.call(e),v=(b=t.avatar)!==null&&b!==void 0?b:(l=e.avatar)===null||l===void 0?void 0:l.call(e),_=o("div",{class:`${a.value}-item-meta-content`},[i&&o("h4",{class:`${a.value}-item-meta-title`},[i]),r&&o("div",{class:`${a.value}-item-meta-description`},[r])]);return o("div",{class:s},[v&&o("div",{class:`${a.value}-item-meta-avatar`},[v]),(i||r)&&_])}}}),Q=Symbol("ListContextKey");var V=globalThis&&globalThis.__rest||function(t,c){var e={};for(var a in t)Object.prototype.hasOwnProperty.call(t,a)&&c.indexOf(a)<0&&(e[a]=t[a]);if(t!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,a=Object.getOwnPropertySymbols(t);n<a.length;n++)c.indexOf(a[n])<0&&Object.prototype.propertyIsEnumerable.call(t,a[n])&&(e[a[n]]=t[a[n]]);return e};const X=()=>({prefixCls:String,extra:p.any,actions:p.array,grid:Object,colStyle:{type:Object,default:void 0}}),B=A({compatConfig:{MODE:3},name:"AListItem",inheritAttrs:!1,Meta:F,props:X(),slots:Object,setup(t,c){let{slots:e,attrs:a}=c;const{itemLayout:n,grid:f}=M(Q,{grid:O(),itemLayout:O()}),{prefixCls:m}=E("list",t),y=()=>{var l;const s=((l=e.default)===null||l===void 0?void 0:l.call(e))||[];let i;return s.forEach(r=>{k(r)&&!D(r)&&(i=!0)}),i&&s.length>1},b=()=>{var l,s;const i=(l=t.extra)!==null&&l!==void 0?l:(s=e.extra)===null||s===void 0?void 0:s.call(e);return n.value==="vertical"?!!i:!y()};return()=>{var l,s,i,r,v;const{class:_}=a,S=V(a,["class"]),u=m.value,g=(l=t.extra)!==null&&l!==void 0?l:(s=e.extra)===null||s===void 0?void 0:s.call(e),x=(i=e.default)===null||i===void 0?void 0:i.call(e);let d=(r=t.actions)!==null&&r!==void 0?r:w((v=e.actions)===null||v===void 0?void 0:v.call(e));d=d&&!Array.isArray(d)?[d]:d;const I=d&&d.length>0&&o("ul",{class:`${u}-item-action`,key:"actions"},[d.map((L,h)=>o("li",{key:`${u}-item-action-${h}`},[L,h!==d.length-1&&o("em",{class:`${u}-item-action-split`},null)]))]),j=f.value?"div":"li",C=o(j,$($({},S),{},{class:T(`${u}-item`,{[`${u}-item-no-flex`]:!b()},_)}),{default:()=>[n.value==="vertical"&&g?[o("div",{class:`${u}-item-main`,key:"content"},[x,I]),o("div",{class:`${u}-item-extra`,key:"extra"},[g])]:[x,I,N(g,{key:"extra"})]]});return f.value?o(P,{flex:1,style:t.colStyle},{default:()=>[C]}):C}}});export{B as A,F as I,Q as L};
//# sourceMappingURL=Item.09282896.js.map
