import{a as e,A as a,B as i}from"./Text.3b774738.js";import{A as o}from"./Link.e028ce0e.js";import{A as r}from"./Paragraph.482f5128.js";import{A as d}from"./Title.9673e08a.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="b89ad0d4-9dc3-4018-9a28-030ee15585c3",n._sentryDebugIdIdentifier="sentry-dbid-b89ad0d4-9dc3-4018-9a28-030ee15585c3")}catch{}})();e.Text=a;e.Title=d;e.Paragraph=r;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,d),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.5bcf94e8.js.map
