import{U as i}from"./outputWidgets.260a3c99.js";import{c as a,d as f}from"./index.bbd787e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="6075b675-36f4-4fc6-9521-49e86c814fc0",e._sentryDebugIdIdentifier="sentry-dbid-6075b675-36f4-4fc6-9521-49e86c814fc0")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:m,QuarterPicker:o,RangePicker:c}=a(f),b=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.5d0affda.js.map
