import{B as d}from"./BookOutlined.9a33e452.js";import{d as f,b as a,c as l,w as o,f as c,u as n,dj as u,eu as b,aq as i,aC as p,bE as y}from"./outputWidgets.260a3c99.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b930125a-4b0e-4ff3-9cb9-431a153bf750",t._sentryDebugIdIdentifier="sentry-dbid-b930125a-4b0e-4ff3-9cb9-431a153bf750")}catch{}})();const k=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[c(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),b(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.e08dd3ee.js.map
