import{d as g,eA as y,o as _,u as e,b as p,c as b,eu as w,f as o,w as a,bf as x,aq as l,bE as h,e as I,eD as C}from"./outputWidgets.260a3c99.js";import{c}from"./router.c6bba0da.js";import"./index.16d63baf.js";import{O as k}from"./organization.208a3090.js";import{a as A}from"./asyncComputed.61df0e0c.js";import{A as D}from"./Title.9673e08a.js";import{A as v}from"./index.34fd2dd9.js";import{A as B}from"./index.1545a14c.js";import{C as N}from"./Card.a6a7eb10.js";import"./Form.46e378f9.js";import"./hasIn.8ab3cbf4.js";import"./popupNotifcation.87bdba7f.js";import"./index.cf4c23b9.js";import"./record.608c7c8c.js";import"./pubsub.ab27f2c0.js";import"./Text.3b774738.js";import"./index.8ca3bef1.js";import"./TabPane.ccb73962.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="0be267df-7f71-48df-9be3-6ecb1136c6cd",t._sentryDebugIdIdentifier="sentry-dbid-0be267df-7f71-48df-9be3-6ecb1136c6cd")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},Z=g({__name:"Billing",setup(t){const r=y().params.organizationId,{loading:f,result:m}=A(()=>k.get(r));_(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const u=()=>c.showNewMessage("I want to upgrade my plan");return(E,V)=>e(f)?(p(),b(e(x),{key:0})):(p(),w("div",z,[o(e(v),{justify:"space-between",align:"center"},{default:a(()=>[o(e(D),{level:3},{default:a(()=>[l("Current plan")]),_:1})]),_:1}),o(e(B),{style:{"margin-top":"0"}}),o(e(N),{style:{width:"300px"},title:"Plan"},{extra:a(()=>[o(e(h),{onClick:u},{default:a(()=>[l("Upgrade")]),_:1})]),default:a(()=>{var s,i,d;return[I("div",M,C((d=(i=(s=e(m))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{Z as default};
//# sourceMappingURL=Billing.bb9e06d5.js.map
