import{F as b}from"./PhArrowSquareOut.vue.fc3fa822.js";import{d as k,H as v,b as o,eu as u,c,u as a,w as n,ev as w,bf as C,aq as m,aC as h,eB as x,f as d,eD as D,v as I}from"./outputWidgets.260a3c99.js";import"./index.5bcf94e8.js";import"./index.38e39792.js";import{A as y}from"./index.34fd2dd9.js";import{a as _}from"./Text.3b774738.js";import{C as B}from"./Card.a6a7eb10.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="321a4aa3-cc7b-47aa-af1a-101a4d0ebec4",t._sentryDebugIdIdentifier="sentry-dbid-321a4aa3-cc7b-47aa-af1a-101a4d0ebec4")}catch{}})();const H=k({__name:"HomeContent",props:{loading:{type:Boolean},workspace:{}},emits:["form-click"],setup(t,{emit:r}){const p=t,f=v(()=>{var e,i;return(i=(e=p.workspace)==null?void 0:e.sidebar.filter(s=>s.visible))!=null?i:[]});function g(e){r("form-click",e)}return(e,i)=>{var s;return o(),u("div",{class:"container",style:w({backgroundColor:(s=e.workspace)==null?void 0:s.theme})},[e.loading?(o(),c(a(C),{key:0})):f.value.length===0?(o(),c(a(_),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[m(" There are no public forms available ")]),_:1})):(o(),c(a(y),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(o(!0),u(h,null,x(f.value,l=>(o(),c(a(B),{key:l.id,class:"form-card",onClick:F=>g(l.path)},{default:n(()=>[d(a(y),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[d(a(_),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[m(D(l.name),1)]),_:2},1024),d(a(b),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const j=I(H,[["__scopeId","data-v-e246816b"]]);export{j as H};
//# sourceMappingURL=HomeContent.01e82d7d.js.map
