import{d as r,b as n,eu as t,dj as s,e as a,ey as d,ew as i,v as c}from"./outputWidgets.260a3c99.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="00343b53-c77d-4936-9db8-80285242d251",o._sentryDebugIdIdentifier="sentry-dbid-00343b53-c77d-4936-9db8-80285242d251")}catch{}})();const u={key:0,class:"canvas-container"},v={class:"canvas-content"},f={class:"canvas-absolute"},_={class:"canvas-footer"},y={key:1,class:"content-container"},b={key:0,class:"content-footer"},p=r({__name:"BaseLayout",props:{fullCanvas:{type:Boolean},noMargins:{type:Boolean}},setup(o){return(e,l)=>(n(),t("div",{class:d(["base-layout",{"full-canvas":e.fullCanvas}])},[s(e.$slots,"navbar",{},void 0,!0),a("div",{class:d(["middle-layout",{"full-canvas":e.fullCanvas}])},[s(e.$slots,"sidebar",{},void 0,!0),e.fullCanvas?(n(),t("div",u,[a("div",v,[a("div",f,[s(e.$slots,"content",{},void 0,!0)])]),a("div",_,[s(e.$slots,"footer",{},void 0,!0)])])):(n(),t("div",y,[a("div",{class:d(["content-layout",{"no-margins":e.noMargins}])},[s(e.$slots,"content",{},void 0,!0)],2)]))],2),e.fullCanvas?i("",!0):(n(),t("div",b,[s(e.$slots,"footer",{},void 0,!0)]))],2))}});const g=c(p,[["__scopeId","data-v-d7175bf5"]]);export{g as B};
//# sourceMappingURL=BaseLayout.30d191dc.js.map
