import{u as n}from"./index.76924dfa.js";import"./outputWidgets.260a3c99.js";import{r as s,w as a}from"./runnerData.90345b76.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b8c6c1a2-4005-4e89-883f-543d47ce9a84",t._sentryDebugIdIdentifier="sentry-dbid-b8c6c1a2-4005-4e89-883f-543d47ce9a84")}catch{}})();async function c(t){const e=await fetch(`/_pages/${t}`,{headers:n.authHeaders()});if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:r}=await e.json();return r?s(r):null}async function i(){const t=await fetch("/_workspace");if(t.status!=200)return a({});const e=await t.json();return a(e)}export{c as f,i as g};
//# sourceMappingURL=api.8917e54c.js.map
