import{C as t,E as i,K as d,a as f,M as b,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.6fb8edf1.js";import"./outputWidgets.260a3c99.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="aab8068c-0517-44e2-a57a-8a471b0524f5",e._sentryDebugIdIdentifier="sentry-dbid-aab8068c-0517-44e2-a57a-8a471b0524f5")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,b as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.4d2b2924.js.map
