import{u as t,a as u}from"./index.76924dfa.js";import{d as l,r as f,b as d,eu as c,f as n,u as e}from"./outputWidgets.260a3c99.js";import{g as b}from"./api.8917e54c.js";import{K as y,P as g,L as _}from"./repository.69b3cc6b.js";import{P as k}from"./PlayerNavbar.2e825223.js";import{a as w}from"./asyncComputed.61df0e0c.js";import"./pubsub.ab27f2c0.js";import"./fetch.642bd10d.js";import"./runnerData.90345b76.js";import"./url.13938513.js";import"./workspaces.2f7f8b14.js";import"./record.608c7c8c.js";import"./scripts.7e47dba2.js";import"./envVars.6745b705.js";import"./api.24a1a6cb.js";import"./index.cf4c23b9.js";import"./metadata.1f8b8ac9.js";import"./PhCheckCircle.vue.8c5f3095.js";import"./PhScroll.vue.87452035.js";import"./PhWebhooksLogo.vue.f190657b.js";import"./ant-design.16592543.js";import"./index.30985d18.js";import"./Modal.6a26a016.js";import"./Text.3b774738.js";import"./index.34fd2dd9.js";import"./index.a74fba23.js";import"./index.233d86bf.js";import"./Paragraph.482f5128.js";import"./index.5bcf94e8.js";import"./Link.e028ce0e.js";import"./Title.9673e08a.js";import"./index.ede42218.js";import"./CollapsePanel.e726c946.js";import"./index.1545a14c.js";import"./index.2a90a136.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.ee180c2e.js";import"./Card.a6a7eb10.js";import"./index.8ca3bef1.js";import"./TabPane.ccb73962.js";import"./hasIn.8ab3cbf4.js";import"./vuedraggable.umd.e50b8ef5.js";import"./index.f8d85462.js";import"./Form.46e378f9.js";import"./PhKanban.vue.ac9ff90f.js";import"./PhSignOut.vue.7cf286a2.js";import"./index.b2703a93.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="8313d06c-e284-4574-9f41-480aa646f8eb",r._sentryDebugIdIdentifier="sentry-dbid-8313d06c-e284-4574-9f41-480aa646f8eb")}catch{}})();const yr=l({__name:"Kanban",setup(r){const o=new g(t),a=new _("kanban"),m=f(t.getUser()),{result:p}=w(b),s=()=>{t.removeUser(),u.push({name:"playerHome"})};return(v,h)=>{var i;return d(),c("div",null,[n(k,{"runner-data":e(p),"show-kanban":!1,"is-kanban-visible":!1,"user-email":(i=m.value)==null?void 0:i.claims.email,onLogout:s},null,8,["runner-data","user-email"]),n(y,{"kanban-repository":e(o),storage:e(a)},null,8,["kanban-repository","storage"])])}}});export{yr as default};
//# sourceMappingURL=Kanban.be63d758.js.map
