import{B as n,R as t}from"./Badge.70e8e9e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="53158d04-64fd-4930-85f5-6339ed8aea42",e._sentryDebugIdIdentifier="sentry-dbid-53158d04-64fd-4930-85f5-6339ed8aea42")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.0821e7cf.js.map
